# Changelog

## 0.2.1 ([Milestone](https://codeberg.org/bovine/almabtrieb/milestone/10246))

- Add automation of release [almabtrieb#13](https://codeberg.org/bovine/almabtrieb/issues/13)
- Add name argument to create actor [almabtrieb#12](https://codeberg.org/bovine/almabtrieb/issues/12)

## 0.2.0

- Change interface, get rid of `connect` method
- Update to new Cattle Drive version

## 0.1.3

- Validate used method in trigger against the allowed methods from `method_information` in the info response.

## 0.1.2

- Set RabbitMQ queues to auto delete

## 0.1.1

- Fix [almabtrieb#7](https://codeberg.org/bovine/almabtrieb/issues/7)

## 0.1.0

Initial version
